@@ -568,9 +568,7 @@ class FuseFaceUltraRequest(AbstractModel):
 ●素材图片限制：图片中面部尺寸大于34 * 34；图片尺寸大于64 * 64，小于8000*8000（单边限制）。图片url或者图片 base64 数据，base64 编码后大小不可超过10M（图片编码之后可能会大30%左右，建议合理控制图片大小）
 ●支持图片格式：支持jpg或png
         :type ModelImage: str
-        :param _FusionUltraParam: 图片人脸融合（专业版）效果参数。
-可用于设置拉脸、人脸增强、磨皮、牙齿增强等融合效果参数，生成理想的融合效果。不传默认使用接口推荐值。具体见FusionUltraParam说明
-
+        :param _FusionUltraParam: 图片人脸融合（专业版）效果参数。可用于设置拉脸、人脸增强、磨皮、牙齿增强、妆容迁移等融合效果参数，生成理想的融合效果。不传默认使用接口推荐值。具体见FusionUltraParam说明
         :type FusionUltraParam: :class:`tencentcloud.facefusion.v20220927.models.FusionUltraParam`
         :param _LogoAdd: 为融合结果图添加合成标识的开关，默认为1。
 1：添加标识。
@@ -652,9 +650,7 @@ class FuseFaceUltraRequest(AbstractModel):
 
     @property
     def FusionUltraParam(self):
-        """图片人脸融合（专业版）效果参数。
-可用于设置拉脸、人脸增强、磨皮、牙齿增强等融合效果参数，生成理想的融合效果。不传默认使用接口推荐值。具体见FusionUltraParam说明
-
+        """图片人脸融合（专业版）效果参数。可用于设置拉脸、人脸增强、磨皮、牙齿增强、妆容迁移等融合效果参数，生成理想的融合效果。不传默认使用接口推荐值。具体见FusionUltraParam说明
         :rtype: :class:`tencentcloud.facefusion.v20220927.models.FusionUltraParam`
         """
         return self._FusionUltraParam
@@ -830,12 +826,12 @@ class FusionUltraParam(AbstractModel):
 该参数仅对SwapModelType（模型类型）取值1-5生效
         :type WarpRadio: float
         :param _EnhanceRadio: 人脸增强强度。对整个人脸进行增强，增加清晰度，改善质量。当生成的人脸不够清晰，质感不够好的时候可以设置。取值越大增强强度越大。
-取值范围：0-1之间。默认取值1。
+取值范围：0-1之间。默认取值0.5。
 
 该参数仅对SwapModelType（模型类型）取值1-5生效
         :type EnhanceRadio: float
         :param _MpRadio: 磨皮强度。当生成脸的图像面部显脏时，可进行设置。
-取值范围：0-1之间。默认取值1。
+取值范围：0-1之间。默认取值0.5。
 
 该参数仅对SwapModelType（模型类型）取值1-5生效
         :type MpRadio: float
@@ -881,7 +877,7 @@ class FusionUltraParam(AbstractModel):
     @property
     def EnhanceRadio(self):
         """人脸增强强度。对整个人脸进行增强，增加清晰度，改善质量。当生成的人脸不够清晰，质感不够好的时候可以设置。取值越大增强强度越大。
-取值范围：0-1之间。默认取值1。
+取值范围：0-1之间。默认取值0.5。
 
 该参数仅对SwapModelType（模型类型）取值1-5生效
         :rtype: float
@@ -895,7 +891,7 @@ class FusionUltraParam(AbstractModel):
     @property
     def MpRadio(self):
         """磨皮强度。当生成脸的图像面部显脏时，可进行设置。
-取值范围：0-1之间。默认取值1。
+取值范围：0-1之间。默认取值0.5。
 
 该参数仅对SwapModelType（模型类型）取值1-5生效
         :rtype: float
